@@ -1,4 +1,4 @@
-# Copyright (C) 2019  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2019-2021  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -14,9 +14,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-'''
-Facade classes to make the main PyCdlib object easier to use.
-'''
+"""Facade classes to make the main PyCdlib object easier to use."""
 
 from __future__ import absolute_import
 
@@ -35,7 +33,7 @@ if False:  # pylint: disable=using-constant-test
 
 def iso_path_to_rr_name(iso_path, interchange_level, is_dir):
     # type: (str, int, bool) -> str
-    '''
+    """
     Take an absolute ISO path and generate a corresponding Rock Ridge basename.
 
     Parameters:
@@ -44,7 +42,7 @@ def iso_path_to_rr_name(iso_path, interchange_level, is_dir):
      is_dir - Whether this will be a directory or not.
     Returns:
      The Rock Ridge name as a string.
-    '''
+    """
 
     if iso_path[0] != '/':
         raise pycdlibexception.PyCdlibInvalidInput("iso_path must start with '/'")
@@ -64,9 +62,7 @@ def iso_path_to_rr_name(iso_path, interchange_level, is_dir):
 
 
 class PyCdlibISO9660(object):
-    '''
-    The class representing the PyCdlib ISO9660 facade.
-    '''
+    """The class representing the PyCdlib ISO9660 facade."""
 
     __slots__ = ('pycdlib_obj',)
 
@@ -76,7 +72,7 @@ class PyCdlibISO9660(object):
 
     def get_file_from_iso(self, local_path, iso_path):
         # type: (str, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute ISO path and write it
         out to a local file.
 
@@ -85,12 +81,12 @@ class PyCdlibISO9660(object):
          iso_path - The absolute ISO9660 path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso(local_path, iso_path=iso_path)
 
     def get_file_from_iso_fp(self, outfp, iso_path):
         # type: (BinaryIO, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute ISO path and write it
         out to the file object.
 
@@ -99,12 +95,12 @@ class PyCdlibISO9660(object):
          iso_path - The absolute ISO9660 path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso_fp(outfp, iso_path=iso_path)
 
     def add_fp(self, fp, length, iso_path):
         # type: (BinaryIO, int, str) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the ISO9660 context (and by extension, the Rock Ridge
         context).  If the ISO is a Rock Ridge one, then a Rock Ridge name will
@@ -122,7 +118,7 @@ class PyCdlibISO9660(object):
          iso_path - The ISO9660 absolute path to the file destination on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         rr_name = None
         if self.pycdlib_obj.has_rock_ridge():
             rr_name = iso_path_to_rr_name(iso_path, self.pycdlib_obj.interchange_level, False)
@@ -130,7 +126,7 @@ class PyCdlibISO9660(object):
 
     def add_file(self, filename, iso_path):
         # type: (str, str) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the ISO9660 context (and by extension, the Rock Ridge
         context).  If the ISO is a Rock Ridge one, then a Rock Ridge name will
@@ -143,7 +139,7 @@ class PyCdlibISO9660(object):
          iso_path - The ISO9660 absolute path to the file destination on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         rr_name = None
         if self.pycdlib_obj.has_rock_ridge():
             rr_name = iso_path_to_rr_name(iso_path, self.pycdlib_obj.interchange_level, False)
@@ -151,7 +147,7 @@ class PyCdlibISO9660(object):
 
     def add_directory(self, iso_path):
         # type: (str) -> None
-        '''
+        """
         Add a directory to the ISO9660 context (and by extension, the Rock
         Ridge context).  If the ISO is a Rock Ridge one, then a Rock Ridge name
         will be generated from the ISO path.  For more control over which
@@ -162,7 +158,7 @@ class PyCdlibISO9660(object):
          iso_path - The ISO9660 absolute path to use for the directory.
         Returns:
          Nothing.
-        '''
+        """
         rr_name = None
         if self.pycdlib_obj.has_rock_ridge():
             rr_name = iso_path_to_rr_name(iso_path, self.pycdlib_obj.interchange_level, True)
@@ -170,7 +166,7 @@ class PyCdlibISO9660(object):
 
     def rm_file(self, iso_path):
         # type: (str) -> None
-        '''
+        """
         Remove a file from the ISO.  This removes the data and the listing of
         the file from all contexts.  Due to some complexities of the ISO format,
         removal of zero-byte files from all contexts does not automatically
@@ -181,12 +177,12 @@ class PyCdlibISO9660(object):
          iso_path - The path to the file to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_file(iso_path=iso_path)
 
     def rm_directory(self, iso_path):
         # type: (str) -> None
-        '''
+        """
         Remove a directory from the ISO.  This removes the directory from
         just the ISO9660 context (and by extension, the Rock Ridge context).
         The directory must be empty.
@@ -195,12 +191,12 @@ class PyCdlibISO9660(object):
          iso_path - The path to the directory to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_directory(iso_path=iso_path)
 
     def list_children(self, iso_path):
         # type: (str) -> Generator
-        '''
+        """
         Generate a list of all of the file/directory objects in the
         specified location on the ISO.
 
@@ -210,12 +206,12 @@ class PyCdlibISO9660(object):
          Children of this path.
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.list_children(iso_path=iso_path)
 
     def get_record(self, iso_path):
         # type: (str) -> dr.DirectoryRecord
-        '''
+        """
         Get the directory record for a particular ISO path.
 
         Parameters:
@@ -223,7 +219,7 @@ class PyCdlibISO9660(object):
                     record for.
         Returns:
          A dr.DirectoryRecord object that represents the path.
-        '''
+        """
         ret = self.pycdlib_obj.get_record(iso_path=iso_path)
         if not isinstance(ret, dr.DirectoryRecord):
             raise pycdlibexception.PyCdlibInternalError('Invalid return type from get_record')
@@ -231,7 +227,7 @@ class PyCdlibISO9660(object):
 
     def walk(self, iso_path):
         # type: (str) -> Generator
-        '''
+        """
         Walk the entries on the ISO, starting at the given ISO path.  Similar
         to os.walk(), yield a 3-tuple of (path-to-here, dirlist, filelist)
         for each directory level.
@@ -242,12 +238,12 @@ class PyCdlibISO9660(object):
          3-tuples of (path-to-here, dirlist, filelist)
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.walk(iso_path=iso_path)
 
     def open_file_from_iso(self, iso_path):
         # type: (str) -> pycdlibio.PyCdlibIO
-        '''
+        """
         Open a file for reading in a context manager.  This allows the user to
         operate on the file in user-defined chunks (utilizing the read() method
         of the returned context manager).
@@ -256,14 +252,12 @@ class PyCdlibISO9660(object):
          iso_path - The absolute ISO path to the file on the ISO.
         Returns:
          A PyCdlibIO object allowing access to the file.
-        '''
+        """
         return self.pycdlib_obj.open_file_from_iso(iso_path=iso_path)
 
 
 class PyCdlibJoliet(object):
-    '''
-    The class representing the PyCdlib Joliet facade.
-    '''
+    """The class representing the PyCdlib Joliet facade."""
 
     __slots__ = ('pycdlib_obj',)
 
@@ -275,7 +269,7 @@ class PyCdlibJoliet(object):
 
     def get_file_from_iso(self, local_path, joliet_path):
         # type: (str, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute Joliet path and write
         it out to a local file.
 
@@ -285,12 +279,12 @@ class PyCdlibJoliet(object):
                        with iso_path, rr_path, and udf_path).
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso(local_path, joliet_path=joliet_path)
 
     def get_file_from_iso_fp(self, outfp, joliet_path):
         # type: (BinaryIO, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute Joliet path and write
         it out to the file object.
 
@@ -299,12 +293,12 @@ class PyCdlibJoliet(object):
          joliet_path - The absolute Joliet path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso_fp(outfp, joliet_path=joliet_path)
 
     def add_fp(self, fp, length, joliet_path):
         # type: (BinaryIO, int, str) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the Joliet context.  For more control over which contexts
         a file shows up in, use the 'add_hard_link' API and/or use the regular
@@ -320,7 +314,7 @@ class PyCdlibJoliet(object):
          joliet_path - The Joliet absolute path to the file destination on the ISO.
         Returns:
          Nothing.
-        '''
+        """
 
         # Since Joliet is a totally separate namespace from ISO9660/Rock Ridge,
         # there is no reliable way to find the ISO9660 path from the Joliet
@@ -330,7 +324,7 @@ class PyCdlibJoliet(object):
 
     def add_file(self, filename, joliet_path):
         # type: (str, str) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the Joliet context.  For more control over which contexts
         in which a file shows up, use the 'add_hard_link' API and/or use the
@@ -341,7 +335,7 @@ class PyCdlibJoliet(object):
          joliet_path - The Joliet absolute path to the file destination on the ISO.
         Returns:
          Nothing.
-        '''
+        """
 
         # Since Joliet is a totally separate namespace from ISO9660/Rock Ridge,
         # there is no reliable way to find the ISO9660 path from the Joliet
@@ -351,7 +345,7 @@ class PyCdlibJoliet(object):
 
     def add_directory(self, joliet_path):
         # type: (str) -> None
-        '''
+        """
         Add a directory to the Joliet context.  For more control over which
         contexts in which a directory shows up, use the regular PyCdlib object
         (not this facade).
@@ -360,12 +354,12 @@ class PyCdlibJoliet(object):
          iso_path - The ISO9660 absolute path to use for the directory.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.add_directory(joliet_path=joliet_path)
 
     def rm_file(self, joliet_path):
         # type: (str) -> None
-        '''
+        """
         Remove a file from the ISO.  This removes the data and the listing of
         the file from all contexts.  Due to some complexities of the ISO format,
         removal of zero-byte files from all contexts does not automatically
@@ -376,12 +370,12 @@ class PyCdlibJoliet(object):
          joliet_path - The path to the file to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_file(joliet_path=joliet_path)
 
     def rm_directory(self, joliet_path):
         # type: (str) -> None
-        '''
+        """
         Remove a directory from the ISO.  This removes the directory from
         just the Joliet context.  The directory must be empty.
 
@@ -389,12 +383,12 @@ class PyCdlibJoliet(object):
          joliet_path - The path to the directory to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_directory(joliet_path=joliet_path)
 
     def list_children(self, joliet_path):
         # type: (str) -> Generator
-        '''
+        """
         Generate a list of all of the file/directory objects in the
         specified location on the ISO.
 
@@ -404,12 +398,12 @@ class PyCdlibJoliet(object):
          Children of this path.
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.list_children(joliet_path=joliet_path)
 
     def get_record(self, joliet_path):
         # type: (str) -> dr.DirectoryRecord
-        '''
+        """
         Get the directory record for a particular Joliet path.
 
         Parameters:
@@ -417,7 +411,7 @@ class PyCdlibJoliet(object):
                     record for.
         Returns:
          A dr.DirectoryRecord object that represents the path.
-        '''
+        """
         ret = self.pycdlib_obj.get_record(joliet_path=joliet_path)
         if not isinstance(ret, dr.DirectoryRecord):
             raise pycdlibexception.PyCdlibInternalError('Invalid return type from get_record')
@@ -425,7 +419,7 @@ class PyCdlibJoliet(object):
 
     def walk(self, joliet_path):
         # type: (str) -> Generator
-        '''
+        """
         Walk the entries on the Joliet portion of the ISO, starting at the given
         Joliet path.  Similar to os.walk(), yield a 3-tuple of
         (path-to-here, dirlist, filelist) for each directory level.
@@ -436,12 +430,12 @@ class PyCdlibJoliet(object):
          3-tuples of (path-to-here, dirlist, filelist)
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.walk(joliet_path=joliet_path)
 
     def open_file_from_iso(self, joliet_path):
         # type: (str) -> pycdlibio.PyCdlibIO
-        '''
+        """
         Open a file for reading in a context manager.  This allows the user to
         operate on the file in user-defined chunks (utilizing the read() method
         of the returned context manager).
@@ -450,14 +444,12 @@ class PyCdlibJoliet(object):
          joliet_path - The absolute Joliet path to the file on the ISO.
         Returns:
          A PyCdlibIO object allowing access to the file.
-        '''
+        """
         return self.pycdlib_obj.open_file_from_iso(joliet_path=joliet_path)
 
 
 class PyCdlibRockRidge(object):
-    '''
-    The class representing the PyCdlib Rock Ridge facade.
-    '''
+    """The class representing the PyCdlib Rock Ridge facade."""
 
     __slots__ = ('pycdlib_obj',)
 
@@ -469,7 +461,7 @@ class PyCdlibRockRidge(object):
 
     def get_file_from_iso(self, local_path, rr_path):
         # type: (str, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute Rock Ridge path and
         write it out to a local file.
 
@@ -478,12 +470,12 @@ class PyCdlibRockRidge(object):
          rr_path - The absolute Rock Ridge path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso(local_path, rr_path=rr_path)
 
     def get_file_from_iso_fp(self, outfp, rr_path):
         # type: (BinaryIO, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute Rock Ridge path and
         write it out to the file object.
 
@@ -492,12 +484,12 @@ class PyCdlibRockRidge(object):
          joliet_path - The absolute Joliet path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso_fp(outfp, rr_path=rr_path)
 
     def _rr_path_to_iso_path(self, rr_path):
         # type: (str) -> str
-        '''
+        """
         An internal method to convert an ISO9660 path to a Rock Ridge one. This
         is accomplished by finding the Rock Ridge directory record, then
         reconstructing the ISO path by walking up to the root.
@@ -506,7 +498,7 @@ class PyCdlibRockRidge(object):
          rr_path - The Rock Ridge path to generate an ISO9660 path for.
         Returns:
          The ISO9660 path corresponding to the Rock Ridge path.
-        '''
+        """
         if rr_path[0] != '/':
             raise pycdlibexception.PyCdlibInvalidInput("rr_path must start with '/'")
 
@@ -525,7 +517,7 @@ class PyCdlibRockRidge(object):
 
     def _rr_path_to_iso_path_and_rr_name(self, rr_path, is_dir):
         # type: (str, bool) -> Tuple[str, str]
-        '''
+        """
         An internal method to split a Rock Ridge absolute path into an absolute
         ISO9660 path and a Rock Ridge name.  This is accomplished by finding the
         Rock Ridge directory record of the parent, then reconstructing the ISO
@@ -537,7 +529,7 @@ class PyCdlibRockRidge(object):
         Returns:
          A tuple where the first element is the absolute ISO9660 path of the
          parent, and the second element is the Rock Ridge name.
-        '''
+        """
         if rr_path[0] != '/':
             raise pycdlibexception.PyCdlibInvalidInput("rr_path must start with '/'")
 
@@ -569,7 +561,7 @@ class PyCdlibRockRidge(object):
 
     def add_fp(self, fp, length, rr_path, file_mode):
         # type: (BinaryIO, int, str, int) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the Rock Ridge context (and by extension, the ISO9660
         context).  For more control over which contexts a file shows up in, use
@@ -589,14 +581,14 @@ class PyCdlibRockRidge(object):
                      used.
         Returns:
          Nothing.
-        '''
+        """
         iso_path, rr_name = self._rr_path_to_iso_path_and_rr_name(rr_path, False)
         self.pycdlib_obj.add_fp(fp, length, iso_path, rr_name=rr_name,
                                 file_mode=file_mode)
 
     def add_file(self, filename, rr_path, file_mode):
         # type: (str, str, int) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the Rock Ridge context (and by extension, the ISO9660
         context).  For more control over which contexts in which a file shows up,
@@ -611,14 +603,14 @@ class PyCdlibRockRidge(object):
                      used.
         Returns:
          Nothing.
-        '''
+        """
         iso_path, rr_name = self._rr_path_to_iso_path_and_rr_name(rr_path, False)
         self.pycdlib_obj.add_file(filename, iso_path, rr_name=rr_name,
                                   file_mode=file_mode)
 
     def add_directory(self, rr_path, file_mode):
         # type: (str, int) -> None
-        '''
+        """
         Add a directory to the Rock Ridge context (and by extension, the ISO9660
         context).  For more control over which contexts in which a directory
         shows up, use the regular PyCdlib object (not this facade).
@@ -630,14 +622,14 @@ class PyCdlibRockRidge(object):
                      used.
         Returns:
          Nothing.
-        '''
+        """
         iso_path, rr_name = self._rr_path_to_iso_path_and_rr_name(rr_path, True)
         self.pycdlib_obj.add_directory(iso_path=iso_path, rr_name=rr_name,
                                        file_mode=file_mode)
 
     def rm_file(self, rr_path):
         # type: (str) -> None
-        '''
+        """
         Remove a file from the ISO.  This removes the data and the listing of
         the file from all contexts.  Due to some complexities of the ISO format,
         removal of zero-byte files from all contexts does not automatically
@@ -648,12 +640,12 @@ class PyCdlibRockRidge(object):
          rr_path - The path to the file to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_file(self._rr_path_to_iso_path(rr_path))
 
     def rm_directory(self, rr_path):
         # type: (str) -> None
-        '''
+        """
         Remove a directory from the ISO.  This removes the directory from
         just the Rock Ridge context (and by extension, the ISO9660 context).
         The directory must be empty.
@@ -662,12 +654,12 @@ class PyCdlibRockRidge(object):
          rr_path - The path to the directory to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_directory(self._rr_path_to_iso_path(rr_path))
 
     def add_symlink(self, rr_symlink_path, rr_target_path):
         # type: (str, str) -> None
-        '''
+        """
         Add a symlink from rr_symlink_name to the rr_path.
 
         Parameters:
@@ -677,7 +669,7 @@ class PyCdlibRockRidge(object):
                           symlink points to.
         Returns:
          Nothing.
-        '''
+        """
         symlink_path, rr_symlink_name = self._rr_path_to_iso_path_and_rr_name(rr_symlink_path,
                                                                               False)
         self.pycdlib_obj.add_symlink(symlink_path,
@@ -686,7 +678,7 @@ class PyCdlibRockRidge(object):
 
     def list_children(self, rr_path):
         # type: (str) -> Generator
-        '''
+        """
         Generate a list of all of the file/directory objects in the
         specified location on the ISO.
 
@@ -696,12 +688,12 @@ class PyCdlibRockRidge(object):
          Children of this path.
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.list_children(rr_path=rr_path)
 
     def get_record(self, rr_path):
         # type: (str) -> dr.DirectoryRecord
-        '''
+        """
         Get the directory record for a particular ISO path.
 
         Parameters:
@@ -709,7 +701,7 @@ class PyCdlibRockRidge(object):
                    record for.
         Returns:
          A dr.DirectoryRecord object that represents the path.
-        '''
+        """
         ret = self.pycdlib_obj.get_record(rr_path=rr_path)
         if not isinstance(ret, dr.DirectoryRecord):
             raise pycdlibexception.PyCdlibInternalError('Invalid return type from get_record')
@@ -717,7 +709,7 @@ class PyCdlibRockRidge(object):
 
     def walk(self, rr_path):
         # type: (str) -> Generator
-        '''
+        """
         Walk the entries on the ISO, starting at the given Rock Ridge path.
         Similar to os.walk(), yield a 3-tuple of
         (path-to-here, dirlist, filelist) for each directory level.
@@ -728,12 +720,12 @@ class PyCdlibRockRidge(object):
          3-tuples of (path-to-here, dirlist, filelist)
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.walk(rr_path=rr_path)
 
     def open_file_from_iso(self, rr_path):
         # type: (str) -> pycdlibio.PyCdlibIO
-        '''
+        """
         Open a file for reading in a context manager.  This allows the user to
         operate on the file in user-defined chunks (utilizing the read() method
         of the returned context manager).
@@ -742,14 +734,12 @@ class PyCdlibRockRidge(object):
          rr_path - The absolute Rock Ridge path to the file on the ISO.
         Returns:
          A PyCdlibIO object allowing access to the file.
-        '''
+        """
         return self.pycdlib_obj.open_file_from_iso(rr_path=rr_path)
 
 
 class PyCdlibUDF(object):
-    '''
-    The class representing the PyCdlib UDF facade.
-    '''
+    """The class representing the PyCdlib UDF facade."""
 
     __slots__ = ('pycdlib_obj',)
 
@@ -761,7 +751,7 @@ class PyCdlibUDF(object):
 
     def get_file_from_iso(self, local_path, udf_path):
         # type: (str, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute UDF path and write it
         out to a local file.
 
@@ -770,12 +760,12 @@ class PyCdlibUDF(object):
          udf_path - The absolute UDF path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso(local_path, udf_path=udf_path)
 
     def get_file_from_iso_fp(self, outfp, udf_path):
         # type: (BinaryIO, str) -> None
-        '''
+        """
         Fetch a single file from the ISO via an absolute UDF path and write it
         out to the file object.
 
@@ -784,12 +774,12 @@ class PyCdlibUDF(object):
          udf_path - The absolute UDF path to lookup on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.get_file_from_iso_fp(outfp, udf_path=udf_path)
 
     def add_fp(self, fp, length, udf_path):
         # type: (BinaryIO, int, str) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the UDF context.  For more control over which contexts
         a file shows up in, use the 'add_hard_link' API and/or use the regular
@@ -805,12 +795,12 @@ class PyCdlibUDF(object):
          udf_path - The UDF absolute path to the file destination on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.add_fp(fp, length, udf_path=udf_path)
 
     def add_file(self, filename, udf_path):
         # type: (str, str) -> None
-        '''
+        """
         Add a file to the ISO.  While using this facade, a file will only be
         added to the UDF context.  For more control over which contexts
         in which a file shows up, use the 'add_hard_link' API and/or use the
@@ -821,12 +811,12 @@ class PyCdlibUDF(object):
          udf_path - The UDF absolute path to the file destination on the ISO.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.add_file(filename, udf_path=udf_path)
 
     def add_directory(self, udf_path):
         # type: (str) -> None
-        '''
+        """
         Add a directory to the UDF context.  For more control over which
         contexts in which a directory shows up, use the regular PyCdlib object
         (not this facade).
@@ -835,12 +825,12 @@ class PyCdlibUDF(object):
          udf_path - The UDF absolute path to use for the directory.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.add_directory(udf_path=udf_path)
 
     def rm_file(self, udf_path):
         # type: (str) -> None
-        '''
+        """
         Remove a file from the ISO.  This removes the data and the listing of
         the file from all contexts.  Due to some complexities of the ISO format,
         removal of zero-byte files from all contexts does not automatically
@@ -851,12 +841,12 @@ class PyCdlibUDF(object):
          udf_path - The path to the file to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_file(udf_path=udf_path)
 
     def rm_directory(self, udf_path):
         # type: (str) -> None
-        '''
+        """
         Remove a directory from the ISO.  This removes the directory from
         just the UDF context.  The directory must be empty.
 
@@ -864,12 +854,12 @@ class PyCdlibUDF(object):
          udf_path - The path to the directory to remove.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.rm_directory(udf_path=udf_path)
 
     def add_symlink(self, udf_symlink_path, udf_target):
         # type: (str, str) -> None
-        '''
+        """
         Add a symlink from udf_symlink_path to udf_target.
 
         Parameters:
@@ -878,13 +868,13 @@ class PyCdlibUDF(object):
                       points to.
         Returns:
          Nothing.
-        '''
+        """
         self.pycdlib_obj.add_symlink(udf_symlink_path=udf_symlink_path,
                                      udf_target=udf_target)
 
     def list_children(self, udf_path):
         # type: (str) -> Generator
-        '''
+        """
         Generate a list of all of the file/directory objects in the
         specified location on the ISO.
 
@@ -894,12 +884,12 @@ class PyCdlibUDF(object):
          Children of this path.
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.list_children(udf_path=udf_path)
 
     def get_record(self, udf_path):
         # type: (str) -> udfmod.UDFFileEntry
-        '''
+        """
         Get the directory record for a particular UDF path.
 
         Parameters:
@@ -907,7 +897,7 @@ class PyCdlibUDF(object):
                     record for.
         Returns:
          A udf.UDFFileEntry object that represents the path.
-        '''
+        """
         ret = self.pycdlib_obj.get_record(udf_path=udf_path)
         if not isinstance(ret, udfmod.UDFFileEntry):
             raise pycdlibexception.PyCdlibInternalError('Invalid return type from get_record')
@@ -915,7 +905,7 @@ class PyCdlibUDF(object):
 
     def walk(self, udf_path):
         # type: (str) -> Generator
-        '''
+        """
         Walk the entries on the ISO, starting at the given UDF path.  Similar
         to os.walk(), yield a 3-tuple of (path-to-here, dirlist, filelist)
         for each directory level.
@@ -926,12 +916,12 @@ class PyCdlibUDF(object):
          3-tuples of (path-to-here, dirlist, filelist)
         Returns:
          Nothing.
-        '''
+        """
         return self.pycdlib_obj.walk(udf_path=udf_path)
 
     def open_file_from_iso(self, udf_path):
         # type: (str) -> pycdlibio.PyCdlibIO
-        '''
+        """
         Open a file for reading in a context manager.  This allows the user to
         operate on the file in user-defined chunks (utilizing the read() method
         of the returned context manager).
@@ -940,5 +930,5 @@ class PyCdlibUDF(object):
          udf_path - The absolute UDF path to the file on the ISO.
         Returns:
          A PyCdlibIO object allowing access to the file.
-        '''
+        """
         return self.pycdlib_obj.open_file_from_iso(udf_path=udf_path)
